@@ -55,6 +55,25 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
 
         jsii.create(CfnMicrosoftAD, self, [scope, id, props])
 
+    @jsii.member(jsii_name="fromCloudFormation")
+    @builtins.classmethod
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnMicrosoftAD":
+        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
+
+        Used in the @aws-cdk/cloudformation-include module.
+
+        :param scope: -
+        :param id: -
+        :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
+
+        stability
+        :stability: experimental
+        """
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -370,6 +389,25 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
 
         jsii.create(CfnSimpleAD, self, [scope, id, props])
 
+    @jsii.member(jsii_name="fromCloudFormation")
+    @builtins.classmethod
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnSimpleAD":
+        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
+
+        Used in the @aws-cdk/cloudformation-include module.
+
+        :param scope: -
+        :param id: -
+        :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
+
+        stability
+        :stability: experimental
+        """
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
